import {
  csv,
  select,
  scaleLinear,
  extent,
  axisLeft,
  axisBottom,
  line,
} from 'd3';

const csvUrl = 'co2_mm_mlo.csv';
const parseRow = (d) => {
  d.interpolated = +d.interpolated;
  d.average = +d.average;
  d['decimal date'] = +d['decimal date'];
  return d;
};
const xValue = (d) => d['decimal date'];
const yValue = (d) => d.average;
const y2Value = (d) => d.interpolated;

const margin = {
  top: 20,
  right: 20,
  bottom: 50,
  left: 60,
};

const width = window.innerWidth;
const height = window.innerHeight;

const svg = select('body')
  .selectAll('.viz')
  .data([null])
  .join('svg')
  .attr('class', 'viz')
  .attr('width', width)
  .attr('height', height);

const main = async () => {
  const data = await csv(csvUrl, parseRow);
  
  const { top, right, bottom, left } = margin;

  const x = scaleLinear()
    .domain(extent(data, xValue))
    .range([left, width - right]);

  const y = scaleLinear()
    .domain(extent(data, yValue))
    .range([height - bottom, top]);

  svg
    .selectAll('.line')
    .data([null])
    .join('path')
    .attr('class', 'line')
    .attr(
      'd',
      line()
        .x((d) => x(xValue(d)))
        .y((d) => y(yValue(d)))(data)
    );

  // svg
  //   .selectAll('.line-2')
  //   .data([null])
  //   .join('path')
  //   .attr('class', 'line-2')
  //   .attr(
  //     'd',
  //     line()
  //       .x((d) => x(xValue(d)))
  //       .y((d) => y(y2Value(d)))(data)
  //   )
  //   .attr('class', 'line-2');

  svg
    .selectAll('.y-axis')
    .data([null])
    .join('g')
    .attr('class', 'y-axis')
    .attr('transform', `translate(${left},0)`)
    .call(
      axisLeft(y)
        .tickSize(-(width - left - right))
        .tickPadding(10)
    )
    .selectAll('.domain')
    .remove();

  svg
    .selectAll('.x-axis')
    .data([null])
    .join('g')
    .attr('class', 'x-axis')
    .attr('transform', `translate(0,${height - bottom})`)
    .call(
      axisBottom(x)
        .tickSize(-(height - top - bottom))
        .tickFormat((d) => d)
        .tickPadding(12)
    )
    .selectAll('.domain')
    .remove();
};
main();
